pub fn run_explicit_workspace_v1(
configuration_path: &Path,
source_specs: &[CliExplicitSourceSpecV1],
verify_clean_equivalence: bool,
) -> Result<CliWorkspaceResultV1, CliWorkspaceErrorV1>Expand description
Executes one complete, explicitly supplied project as a one-package L7 workspace. Package discovery is intentionally not part of this command.